==> dia-0.86.tar.gz: dia-0.86/objects/network/network.c <==
/* Dia -- an diagram creation/manipulation program
 * Copyright (C) 1998 Alexander Larsson
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#include "object.h"
#include "sheet.h"

#include "config.h"
#include "intl.h"
#include "network.h"
#include "plug-ins.h"

Color computer_color = { 0.7, 0.7, 0.7 };

extern ObjectType computer_type;
extern ObjectType monitor_type;
extern ObjectType disc_type;
extern ObjectType bus_type;
extern ObjectType bus_type_std;
extern ObjectType printer_type;
extern ObjectType flash_type;
extern ObjectType hub_type;
extern ObjectType modularswitch_type;
extern ObjectType rj45plug_type;
extern ObjectType sceadplug_type;
extern ObjectType modem_type;
extern ObjectType antenna_type;

DIA_PLUGIN_CHECK_INIT

PluginInitResult
dia_plugin_init(PluginInfo *info)
{
  if (!dia_plugin_info_init(info, "Network", _("Network diagram objects"),
			    NULL, NULL))
    return DIA_PLUGIN_INIT_ERROR;

  object_register_type(&computer_type);
  object_register_type(&monitor_type);
  object_register_type(&disc_type);
  object_register_type(&bus_type_std);
  object_register_type(&bus_type);
  object_register_type(&printer_type);
  object_register_type(&flash_type);
  object_register_type(&hub_type);
  object_register_type(&modularswitch_type);
  object_register_type(&rj45plug_type);
  object_register_type(&sceadplug_type);
  object_register_type(&modem_type);
  object_register_type(&antenna_type);

  return DIA_PLUGIN_INIT_OK;
}

==> dia_0.88.1.orig.tar.gz: dia-0.88.1.orig/objects/network/network.c <==
/* Dia -- an diagram creation/manipulation program
 * Copyright (C) 1998 Alexander Larsson
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "object.h"
#include "sheet.h"

#include "intl.h"
#include "network.h"
#include "plug-ins.h"

Color computer_color = { 0.7, 0.7, 0.7 };

extern ObjectType computer_type;
extern ObjectType monitor_type;
extern ObjectType disc_type;
extern ObjectType bus_type;
extern ObjectType bus_type_std;
extern ObjectType printer_type;
extern ObjectType flash_type;
extern ObjectType wanlink_type;
extern ObjectType hub_type;
extern ObjectType modularswitch_type;
extern ObjectType rj45plug_type;
extern ObjectType sceadplug_type;
extern ObjectType modem_type;
extern ObjectType antenna_type;

DIA_PLUGIN_CHECK_INIT

PluginInitResult
dia_plugin_init(PluginInfo *info)
{
  if (!dia_plugin_info_init(info, "Network", _("Network diagram objects"),
			    NULL, NULL))
    return DIA_PLUGIN_INIT_ERROR;

  object_register_type(&computer_type);
  object_register_type(&monitor_type);
  object_register_type(&disc_type);
  object_register_type(&bus_type_std);
  object_register_type(&bus_type);
  object_register_type(&printer_type);
  object_register_type(&flash_type);
  object_register_type(&wanlink_type);
  object_register_type(&hub_type);
  object_register_type(&modularswitch_type);
  object_register_type(&rj45plug_type);
  object_register_type(&sceadplug_type);
  object_register_type(&modem_type);
  object_register_type(&antenna_type);

  return DIA_PLUGIN_INIT_OK;
}
